@@ -25,7 +25,7 @@ from paho.mqtt.client import Client  as ClientMQTT
 from paho.mqtt import publish as MQTTPublish
 from paho.mqtt import subscribe as MQTTSubscribe
 
-#_LOGGER = logging.getLogger(__name__)
+_LOGGER = logging.getLogger(__name__)
 
 # These consts define all of the vocabulary used by this library when presenting various states and components.
 # Applications implementing this library should import these rather than hard-code the strings, for future-proofing.
@@ -195,7 +195,7 @@ class EcoVacsAPI:
         }
         
         self.verify_ssl = str_to_bool_or_cert(verify_ssl)
-        #_LOGGER.debug("Setting up EcoVacsAPI")
+        _LOGGER.debug("Setting up EcoVacsAPI")
         self.resource = device_id[0:8]
         self.country = country
         self.continent = continent
@@ -239,10 +239,10 @@ class EcoVacsAPI:
         if json['code'] == '0000':
             return json['data']
         elif json['code'] == '1005':
-            #_LOGGER.warning("incorrect email or password")
+            _LOGGER.warning("incorrect email or password")
             raise ValueError("incorrect email or password")
         else:
-            #_LOGGER.error("call to {} failed with {}".format(function, json))
+            _LOGGER.error("call to {} failed with {}".format(function, json))
             raise RuntimeError("failure code {} ({}) for call {} and parameters {}".format(
                 json['code'], json['msg'], function, args))
 
@@ -256,7 +256,7 @@ class EcoVacsAPI:
         if json['result'] == 'ok':
             return json
         else:
-            #_LOGGER.error("call to {} failed with {}".format(function, json))
+            _LOGGER.error("call to {} failed with {}".format(function, json))
             raise RuntimeError(
                 "failure {} ({}) for call {} and parameters {}".format(json['error'], json['errno'], function, params))
 
@@ -288,20 +288,20 @@ class EcoVacsAPI:
             elif json['result'] == 'fail':
                 if json['error'] == 'set token error.': # If it is a set token error try again
                     if not 'set_token' in kwargs:      
-                        #_LOGGER.warning("loginByItToken set token error, trying again (2/3)")              
+                        _LOGGER.warning("loginByItToken set token error, trying again (2/3)")              
                         return self.__call_portal_api(self.USERSAPI, function, args, verify_ssl=verify_ssl, set_token=1)
                     elif kwargs.get('set_token') == 1:
-                        #_LOGGER.warning("loginByItToken set token error, trying again with ww (3/3)")              
+                        _LOGGER.warning("loginByItToken set token error, trying again with ww (3/3)")              
                         return self.__call_portal_api(self.USERSAPI, function, args, verify_ssl=verify_ssl, set_token=2, continent="ww")
                     else:
-                        #_LOGGER.warning("loginByItToken set token error, failed after 3 attempts")
+                        _LOGGER.warning("loginByItToken set token error, failed after 3 attempts")
                                     
         if api.startswith(self.PRODUCTAPI):
             if json['code'] == 0:
                 return json      
 
         else:
-            #_LOGGER.error("call to {} failed with {}".format(function, json))
+            _LOGGER.error("call to {} failed with {}".format(function, json))
             raise RuntimeError(
                 "failure {} ({}) for call {} and parameters {}".format(json['error'], json['errno'], function, params))
 
@@ -468,7 +468,7 @@ class VacBot():
 
         if not error == '':
             self.errorEvents.notify(error)
-            #_LOGGER.warning("*** error = " + error)
+            _LOGGER.warning("*** error = " + error)
 
     def _handle_life_span(self, event):
         response = event['body']['data'][0]
@@ -477,7 +477,7 @@ class VacBot():
         try:
             type = COMPONENT_FROM_ECOVACS[type]
         except KeyError:
-            #_LOGGER.warning("Unknown component type: '" + type + "'")
+            _LOGGER.warning("Unknown component type: '" + type + "'")
             
         left = int(response['left'])
         total = int(response['total'])
@@ -497,7 +497,7 @@ class VacBot():
         try:
             speed = FAN_SPEED_FROM_ECOVACS[speed]
         except KeyError:
-            #_LOGGER.warning("Unknown fan speed: '" + str(speed) + "'")
+            _LOGGER.warning("Unknown fan speed: '" + str(speed) + "'")
       
         self.fan_speed = speed
         
@@ -517,7 +517,7 @@ class VacBot():
         try:
             amount = WATER_LEVEL_FROM_ECOVACS[amount]
         except KeyError:
-            #_LOGGER.warning("Unknown water level: '" + str(amount) + "'")
+            _LOGGER.warning("Unknown water level: '" + str(amount) + "'")
       
         self.water_level = amount
         
@@ -560,7 +560,7 @@ class VacBot():
                 if self.mapPieces[i] != str(i) + '-' + str(values[i]):
                     self.mapPieces[i] = str(i) + '-' + str(values[i])
                     if str(values[i]) != '1295764014':
-                        #_LOGGER.debug("UPDATING MAP PIECE: " + str(i))
+                        _LOGGER.debug("UPDATING MAP PIECE: " + str(i))
                         self.exc_command('getMinorMap', {'mid': response['mid'],'type': 'ol', 'pieceIndex': i})
 
     def _handle_cached_map(self, event):
@@ -592,7 +592,7 @@ class VacBot():
         try:
             self.battery_status = response['data']['value']
         except ValueError:
-            #_LOGGER.warning("couldn't parse battery status " + response)
+            _LOGGER.warning("couldn't parse battery status " + response)
         else:
             self.batteryEvents.notify(self.battery_status)
 
@@ -612,7 +612,7 @@ class VacBot():
             elif response['msg'] == 'fail' and response['code'] == '3': #Bot in stuck state, example dust bin out
                 status = 'STATE_ERROR'
             else: 
-                #_LOGGER.error("Unknown charging status '" + response['code'] + "'") #Log this so we can identify more errors    
+                _LOGGER.error("Unknown charging status '" + response['code'] + "'") #Log this so we can identify more errors    
 
         if status != 'none':
             self.vacuum_status = status
@@ -629,15 +629,15 @@ class VacBot():
             else:
                 self.is_available = True
         except XMPPError as err:
-            #_LOGGER.warning("Ping did not reach VacBot. Will retry.")
-            #_LOGGER.warning("*** Error type: " + err.etype)
-            #_LOGGER.warning("*** Error condition: " + err.condition)
+            _LOGGER.warning("Ping did not reach VacBot. Will retry.")
+            _LOGGER.warning("*** Error type: " + err.etype)
+            _LOGGER.warning("*** Error condition: " + err.condition)
             self._failed_pings += 1
             if self._failed_pings >= 4:
                 self.is_available = False
 
         except RuntimeError as err:
-            #_LOGGER.warning("Ping did not reach VacBot. Will retry.")
+            _LOGGER.warning("Ping did not reach VacBot. Will retry.")
             self._failed_pings += 1
             if self._failed_pings >= 4:
                 self.is_available = False
@@ -662,9 +662,9 @@ class VacBot():
             self.exc_command('getCachedMapInfo')
             self.exc_command('GetCleanLogs')
         except XMPPError as err:
-            #_LOGGER.warning("Component refresh requests failed to reach VacBot. Will try again later.")
-            #_LOGGER.warning("*** Error type: " + err.etype)
-            #_LOGGER.warning("*** Error condition: " + err.condition)
+            _LOGGER.warning("Component refresh requests failed to reach VacBot. Will try again later.")
+            _LOGGER.warning("*** Error type: " + err.etype)
+            _LOGGER.warning("*** Error condition: " + err.condition)
 
     def refresh_statuses(self):
         try:
@@ -674,18 +674,18 @@ class VacBot():
             self.exc_command('getSpeed')
             self.exc_command('getWaterInfo')
         except XMPPError as err:
-            #_LOGGER.warning("Initial status requests failed to reach VacBot. Will try again on next ping.")
-            #_LOGGER.warning("*** Error type: " + err.etype)
-            #_LOGGER.warning("*** Error condition: " + err.condition)
+            _LOGGER.warning("Initial status requests failed to reach VacBot. Will try again on next ping.")
+            _LOGGER.warning("*** Error type: " + err.etype)
+            _LOGGER.warning("*** Error condition: " + err.condition)
 
     def refresh_liveMap(self):
         try:
             self.exc_command('getMajorMap')
             self.CreatePNGMap()
         except XMPPError as err:
-            #_LOGGER.warning("Initial live map failed to reach VacBot. Will try again on next ping.")
-            #_LOGGER.warning("*** Error type: " + err.etype)
-            #_LOGGER.warning("*** Error condition: " + err.condition)
+            _LOGGER.warning("Initial live map failed to reach VacBot. Will try again on next ping.")
+            _LOGGER.warning("*** Error type: " + err.etype)
+            _LOGGER.warning("*** Error condition: " + err.condition)
 
     def request_all_statuses(self):
         self.refresh_statuses()
@@ -738,7 +738,6 @@ class VacBot():
         self.refresh_statuses()
 
     def exc_command(self, action, params=None, **kwargs):
-        ##_LOGGER.debug(params)
         self.send_command(VacBotCommand(action, params))
 
     def send_command(self, action):
@@ -789,8 +788,6 @@ class VacBot():
                     imageX += 100
                     imageY = 0
 
-            #_LOGGER.debug('PIECE: ' + str(i) + ' X:' + str(imageX) + ' Y:' + str(imageY))
-
             for x in range(100):
                 for y in range(100):
                     if self.buffer[i][x][y] == 0x01: #floor
@@ -896,7 +893,7 @@ class EcoVacsIOTMQ(ClientMQTT):
 
     def on_connect(self, client, userdata, flags, rc):        
         if rc != 0:
-            #_LOGGER.error("EcoVacsMQTT - error connecting with MQTT Return {}".format(rc))
+            _LOGGER.error("EcoVacsMQTT - error connecting with MQTT Return {}".format(rc))
             raise RuntimeError("EcoVacsMQTT - error connecting with MQTT Return {}".format(rc))
                  
         else:
@@ -986,7 +983,7 @@ class EcoVacsIOTMQ(ClientMQTT):
             }
             response = requests.post(url,headers=headers, json=params, timeout=20, verify=verify_ssl) #May think about having timeout as an arg that could be provided in the future
         except requests.exceptions.ReadTimeout:
-            #_LOGGER.warning("call to iotdevmanager failed with ReadTimeout")
+            _LOGGER.warning("call to iotdevmanager failed with ReadTimeout")
             return {}                
         
         json = response.json()
@@ -999,7 +996,7 @@ class EcoVacsIOTMQ(ClientMQTT):
                     return {}
             else:
                 #TODO - Not sure if we want to raise an error yet, just return empty for now
-                #_LOGGER.error("call to iotdevmanager failed with {}".format(json))
+                _LOGGER.error("call to iotdevmanager failed with {}".format(json))
                 return {}
 
     def __call_logs_api(self, args, verify_ssl=True):
@@ -1015,7 +1012,7 @@ class EcoVacsIOTMQ(ClientMQTT):
             }
             response = requests.post(url,headers=headers, json=params, timeout=20, verify=verify_ssl) #May think about having timeout as an arg that could be provided in the future
         except requests.exceptions.ReadTimeout:
-            #_LOGGER.warning("call to logs failed with ReadTimeout")
+            _LOGGER.warning("call to logs failed with ReadTimeout")
             return {}                
         
         json = response.json()
@@ -1028,7 +1025,7 @@ class EcoVacsIOTMQ(ClientMQTT):
                     return {}
             else:
                 #TODO - Not sure if we want to raise an error yet, just return empty for now
-                #_LOGGER.error("call to logs failed with {}".format(json))
+                _LOGGER.error("call to logs failed with {}".format(json))
                 return {}
 
     def _handle_ctl_api(self, action, message):
@@ -1085,7 +1082,7 @@ class EcoVacsIOTMQ(ClientMQTT):
         return jsonstring
 
     def _handle_ctl_mqtt(self, client, userdata, message):
-        ##_LOGGER.warning("EcoVacs MQTT Received Message on Topic: {} - Message: {}".format(message.topic, str(message.payload.decode("utf-8"))))
+        #_LOGGER.warning("EcoVacs MQTT Received Message on Topic: {} - Message: {}".format(message.topic, str(message.payload.decode("utf-8"))))
         as_dict = self._ctl_to_dict_api(message.topic, str(message.payload.decode("utf-8")))
         if as_dict is not None:
             for s in self.ctl_subscribers:
